module.exports = defineTest({
	description:
		'deoptimize concatenation when used as an expression statement to better support es5-shim'
});
